@@ -407,14 +407,14 @@
   (let* ((arch (*arch*))
          (name (cond ((symbol? name) name)
                      ((string? name) (strname->symname name))
-                     (else (error "cbase: bad arg"))))
+                     (else (error "cbase: bad arg:" name))))
          (cmap (or (assoc-ref (*cbase-map*) arch)
                    (let ((cmap (make-cbase-map arch)))
                      (*cbase-map* (acons arch cmap (*cbase-map*)))
                      cmap))))
     (or (assq-ref cmap name)
         (and (memq name cbase-symbols) name)
-        (error "cbase: not found: " name))))
+        (error "cbase: not found:" name))))
 
 ;; @deffn {Procedure} cpointer type
 ;; Generate a C pointer type to @var{type}. To reference or de-reference
@@ -439,7 +439,7 @@
                ((eq? 'void type) type)
                ((symbol? type) (cbase type))
                ((promise? type) type)
-               (else (error "cpointer: bad arg" type)))))
+               (else (error "cpointer: bad arg:" type)))))
     (%make-ctype (sizeof-basetype 'void*) (alignof-basetype 'void*)
                  'pointer (%make-cpointer type (mtypeof-basetype 'void*)) #f)))
 
@@ -681,7 +681,7 @@
          (values type (+ ix (* tag (ctype-size type))))))
       ((pointer)
        (error "ctype-detag: don't call on me for a pointer dereference"))
-      (else (error "bad tag" tag)))))
+      (else (error "bad tag:" tag)))))
 
 ;; @deffn {Procedure} ctype-sel type ix [tag ...] => ((ix . ct) (ix . ct) ...)
 ;; This generate a list of (offset, type) pairs for a type.  The result is
@@ -707,7 +707,7 @@
          ((integer? (car tags))
           (let ((ix (+ ix (* (car tags) (ctype-size type)))))
             (loop (cons (cons ix ct) res) type 0 (cdr tags))))
-         (else (error "bad tag for pointer")))))
+         (else (error "ctype-sel: bad tag for pointer")))))
      (else
       (call-with-values (lambda () (ctype-detag ct ix (car tags)))
         (lambda (ct ix)
@@ -825,7 +825,7 @@
                 (bv (make-bytevector (* value sz))))
            (%make-cdata bv 0 (carray et value))))
         (else
-         (when value (error "can't initialize arrays yet"))
+         (when value (error "make-cdata: can't initialize arrays yet"))
          (%make-cdata (make-bytevector (ctype-size type)) 0 type)))))
     (else
      (let* ((size (ctype-size type))
@@ -877,7 +877,7 @@
                  (addr (let ((addr (mtype-bv-ref (cpointer-mtype cptr) bv ix)))
                          (cond ((eq? '* tag) addr)
                                ((integer? tag) (+ addr (* elsz tag)))
-                               (else (error "cdata-sel: bad tag" tag)))))
+                               (else (error "cdata-sel: bad tag:" tag)))))
                  (eptr (make-pointer addr)))
             (cond
              ((zero? addr)
@@ -916,10 +916,10 @@
       ((array struct union) (%make-cdata bv ix ct))
       ((function)
        (let* ((ti (ctype-info ct))
-              (mtype (cfunction-ptr-mtype ct))
+              (mtype (cfunction-ptr-mtype ti))
               (addr (mtype-bv-ref mtype bv ix))
-              (ptr->proc (cfunction-ptr->proc ct)))
-         (if (zero? addr) (error "cdata-ref: bad function address"))
+              (ptr->proc (cfunction-ptr->proc ti)))
+         (if (zero? addr) (error "cdata-ref: null function address"))
          (ptr->proc (make-pointer addr))))
       (else (error "cdata-ref: giving up")))))
 
@@ -933,7 +933,7 @@
     (if (cdata? value)
         (let ((sz (ctype-size ct)))
           (unless (ctype-equal? (cdata-ct value) ct)
-            (error "cdata-set!: bad arg"))
+            (error "cdata-set!: bad arg:" value))
           (bytevector-copy! (cdata-bv value) (cdata-ix value) bv ix sz))
         (case (ctype-kind ct)
           ((base)
@@ -956,7 +956,7 @@
                (mtype-bv-set! mtype bv ix
                               (pointer-address
                                ((cfunction-proc->ptr (ctype-info pt)) value))))
-              (else (error "cdata-set!: bad arg" value)))))
+              (else (error "cdata-set!: bad arg:" value)))))
           ((bitfield)
            (let* ((bi (ctype-info ct)) (mt (cbitfield-mtype bi))
                   (sh (cbitfield-shift bi)) (wd (cbitfield-width bi))
@@ -1126,7 +1126,7 @@
 (define (cdata*-ref data . tags)
   "- Procedure: cdata*-ref data [tag ...]
      Shortcut for ‘(cdata-ref (cdata* data tag ...))’"
-  (apply cdata-sel data '* tags))
+  (apply cdata-ref data '* tags))
 
 ;; @deffn {Procedure} ccast type data [do-check] => <cdata>
 ;; need to be able to cast array to pointer
@@ -1273,10 +1273,11 @@
           (else `(cpointer ,(cnvt (cpointer-type info))))))
         ((array)
          `(carray ,(cnvt (carray-type info)) ,(carray-length info)))
-        (else (error "pretty-print-ctype: needs work" (ctype-kind type))))))
+        (else (error "pretty-print-ctype: needs work:" (ctype-kind type))))))
   (pretty-print (cnvt type) port))
 
-;; --- not sure about this ===--------------------------------------------------
+
+;; --- not sure about this -----------------------------------------------------
 
 (define (mtype->ffi mtype)
   (or
@@ -1319,7 +1320,7 @@
 (define (unwrap-number arg)
   (cond ((number? arg) arg)
         ((cdata? arg) (cdata-ref arg))
-        (else (error "unwrap-number: bad arg: ~s" arg))))
+        (else (error "unwrap-number: bad arg:" arg))))
 
 ;; @deffn {Procedure} unwrap-number
 ;; doc to come
@@ -1335,7 +1336,7 @@
                         ((pointer) (ctype-info (cpointer-type info)))
                         (else (error "not ok")))))
            ((cfunction-proc->ptr func) arg)))
-        (else (error "unwrap-pointer: bad arg: ~s" arg))))
+        (else (error "unwrap-pointer: bad arg:" arg))))
 
 ;; @deffn {Procedure} unwrap-number
 ;; doc to come
@@ -1343,11 +1344,11 @@
 (define (unwrap-array arg)
   (unless
     (cdata? arg)
-    (error "unwrap-array: bad arg: " arg))
+    (error "unwrap-array: bad arg:" arg))
   (case (cdata-kind arg)
     ((pointer) (cdata-ref arg))
     ((array) (cdata&-ref arg))
-    (else (error "unwrap-array: bad arg: " arg))))
+    (else (error "unwrap-array: bad arg:" arg))))
 
 (define NULL %null-pointer)
 (define (NULL? arg)
