@@ -61,7 +61,7 @@
   #:use-module ((nyacc lex) #:select (cnumstr->scm))
   #:use-module ((nyacc util) #:select (ugly-print))
   #:re-export (*nyacc-version*)
-  #:version (2 00 1))
+  #:version (2 00 2))
 
 ;; maybe change to a record-type
 (define *options* (make-parameter '()))
@@ -398,7 +398,7 @@
            (lambda () (let ((return (mdecl->udecl (cons "~ret" tail))))
                         (function*-wraps return params)))
          (lambda (wrapper unwrapper)
-           `(cfunction ,wrapper ,unwrapper))))
+           `(cpointer (cfunction ,wrapper ,unwrapper)))))
       (`((pointer-to) (pointer-to) (function-returning . ,rest) . ,rest)
        `(cpointer (cbase 'void*)))
       (`((pointer-to) (struct-ref (ident ,name)))
